/*
	TEE -- Implement the Unix TEE filter in Windows
    Copyright (C) 1985, 2003  Norm London, London Computing

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

	norm_london@londoncomputing.com

    Compile with any C compiler, Visual Studio 5 or later or GCC
*/


#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
int main(int argc, char *argv[]) {
    FILE *fi[10], *hlp = stderr;
    int filekt, nextarg, c, append, fileno;
	char arg[1024];
	if (argc > 1)
		strcpy(arg,argv[1]);
	else
		strcpy(arg,"-?");
    if (argc < 2 || strcmp(arg,"?") == 0 || strcmp(arg,"-?") == 0) {
		fprintf(hlp,"TEE Version 1.1, %s\n",__DATE__);
		fprintf(hlp,"\nCopywrite 2003, Norm London, London Computing.\nnorm_london@londoncomputing.com\n\n");
        fprintf(hlp,"This program is free software; you can redistribute it and/or modify\n");
		fprintf(hlp,"it under the terms of the GNU General Public License as published by\n");
		fprintf(hlp,"the Free Software Foundation; either version 2 of the License, or\n");
		fprintf(hlp,"(at your option) any later version.\n\n");
		fprintf(hlp,"This program is distributed in the hope that it will be useful,\n");
		fprintf(hlp,"but WITHOUT ANY WARRANTY; without even the implied warranty of\n");
		fprintf(hlp,"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n");
		fprintf(hlp,"GNU General Public License for more details.\n\n");
		fprintf(hlp,"You should have received a copy of the GNU General Public License\n");
		fprintf(hlp,"along with this program; if not, write to the Free Software\n");
		fprintf(hlp,"Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n\n");

		fputs("Usage is: tee [-a] file1 [... file9]\n",stderr);
		fputs("Copies stdin to stdout and all files (Max 9) in list.\n",stderr);
		fputs("-a -- Append output to files.\n",stderr);
		return 0;
    }

    nextarg = 1;
	// If first argument is -a or -A, then set append
    if (argv[1][0] == '-' && toupper(argv[1][1]) == 'A') {
		append = 1;
		nextarg = 2;
    }
    else
		append = 0;

	// Don't buffer console output
	setvbuf(stdout,NULL,_IONBF,0);

	// Set a 4K buffer for other output
    for (filekt=0;nextarg < argc && nextarg < 9;filekt++,nextarg++) {
		fi[filekt] = fopen(argv[nextarg],append?"a":"w");
		if (fi[filekt] == NULL)
			perror(argv[nextarg]);
		else
			setvbuf(fi[filekt],NULL,_IOFBF,4096);
	}

	// read stdin and send each character read
	// to stdout and to the output file(s).
    while ((c = getchar()) != EOF) {
		putchar(c);
		for (fileno = 0; fileno < filekt; ++fileno)
			if (fi[fileno])
				putc(c,fi[fileno]);
	}

    for (fileno=0; fileno < filekt; ++fileno)
		fclose(fi[fileno]);

	return 0;
}
